
# Slot: directly interacts with


Holds between molecular entities that physically and directly interact with each other

URI: [biolink:directly_interacts_with](https://w3id.org/biolink/vocab/directly_interacts_with)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [interacts with](interacts_with.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | chembio:interacts |
|  | | CTD:interacts_with |
|  | | GAMMA:interacts_with |
| **Narrow Mappings:** | | PHAROS:drug_targets |
|  | | DRUGBANK:chelator |
|  | | GAMMA:antibody_binding |
|  | | GAMMA:pharmacological_chaperone |
|  | | GAMMA:releasing_agent |
|  | | GAMMA:pharmacological_chaperone |
|  | | GAMMA:releasing_agent |
|  | | GAMMA:binder |
|  | | GAMMA:binding |
|  | | GAMMA:ligand |
|  | | GAMMA:cofactor |
|  | | GAMMA:multitarget |
|  | | GAMMA:chaperone |
|  | | GAMMA:component |
|  | | GAMMA:adduct |
|  | | GAMMA:antibody |
|  | | CTD:affects_binding |
|  | | DGIdb:binder |
|  | | DGIdb:cofactor |
| **Broad Mappings:** | | SIO:000203 |
| **Related Mappings:** | | GAMMA:kd |
|  | | GAMMA:kb |
|  | | GAMMA:potency |

